@@ -1,5 +1,3 @@
-package org.apache.maven.reporting.exec;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.reporting.exec;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.reporting.exec;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -29,59 +28,63 @@ import org.codehaus.plexus.configuration.xml.XmlPlexusConfiguration;
 import org.codehaus.plexus.util.xml.Xpp3Dom;
 
 /**
- * Bean which contains necessary informations to build {@link MavenReportExecution} with {@link MavenReportExecutor}: 
+ * Bean which contains necessary informations to build {@link MavenReportExecution} with {@link MavenReportExecutor}:
  * the intent is to store some informations regarding the current Maven execution.
- * 
+ *
  * @author Olivier Lamy
- * @version $Id: MavenReportExecutorRequest.java 1787667 2017-03-19 22:18:45Z hboutemy $
  */
-public class MavenReportExecutorRequest
-{
+public class MavenReportExecutorRequest {
+
+    @Deprecated
     private ArtifactRepository localRepository;
 
     private MavenSession mavenSession;
 
+    private String executionId;
+
     private MavenProject project;
 
     private ReportPlugin[] reportPlugins;
 
-    public ArtifactRepository getLocalRepository()
-    {
+    @Deprecated
+    public ArtifactRepository getLocalRepository() {
         return localRepository;
     }
 
-    public void setLocalRepository( ArtifactRepository localRepository )
-    {
+    @Deprecated
+    public void setLocalRepository(ArtifactRepository localRepository) {
         this.localRepository = localRepository;
     }
 
-    public MavenSession getMavenSession()
-    {
+    public MavenSession getMavenSession() {
         return mavenSession;
     }
 
-    public void setMavenSession( MavenSession mavenSession )
-    {
+    public void setMavenSession(MavenSession mavenSession) {
         this.mavenSession = mavenSession;
     }
 
-    public MavenProject getProject()
-    {
+    public String getExecutionId() {
+        return executionId;
+    }
+
+    public void setExecutionId(String executionId) {
+        this.executionId = executionId;
+    }
+
+    public MavenProject getProject() {
         return project;
     }
 
-    public void setProject( MavenProject project )
-    {
+    public void setProject(MavenProject project) {
         this.project = project;
     }
 
-    public ReportPlugin[] getReportPlugins()
-    {
+    public ReportPlugin[] getReportPlugins() {
         return reportPlugins;
     }
 
-    public void setReportPlugins( ReportPlugin[] reportPlugins )
-    {
+    public void setReportPlugins(ReportPlugin[] reportPlugins) {
         this.reportPlugins = reportPlugins;
     }
 
@@ -91,35 +94,30 @@ public class MavenReportExecutorRequest
      * @param reportPlugins the report plugins from <code>&lt;reporting&gt;</code> section
      * @since 1.4
      */
-    public void setReportPlugins( org.apache.maven.model.ReportPlugin[] reportPlugins )
-    {
-        setReportPlugins( new ReportPlugin[reportPlugins.length] );
+    public void setReportPlugins(org.apache.maven.model.ReportPlugin[] reportPlugins) {
+        setReportPlugins(new ReportPlugin[reportPlugins.length]);
 
         int i = 0;
-        for ( org.apache.maven.model.ReportPlugin r : reportPlugins )
-        {
+        for (org.apache.maven.model.ReportPlugin r : reportPlugins) {
             ReportPlugin p = new ReportPlugin();
-            p.setGroupId( r.getGroupId() );
-            p.setArtifactId( r.getArtifactId() );
-            p.setVersion( r.getVersion() );
-            if ( r.getConfiguration() != null )
-            {
-                p.setConfiguration( new XmlPlexusConfiguration( (Xpp3Dom) r.getConfiguration() ) );
+            p.setGroupId(r.getGroupId());
+            p.setArtifactId(r.getArtifactId());
+            p.setVersion(r.getVersion());
+            if (r.getConfiguration() != null) {
+                p.setConfiguration(new XmlPlexusConfiguration((Xpp3Dom) r.getConfiguration()));
             }
 
-            List<ReportSet> prs = new ArrayList<ReportSet>();
-            for ( org.apache.maven.model.ReportSet rs : r.getReportSets() )
-            {
+            List<ReportSet> prs = new ArrayList<>();
+            for (org.apache.maven.model.ReportSet rs : r.getReportSets()) {
                 ReportSet ps = new ReportSet();
-                ps.setId( rs.getId() );
-                ps.setReports( rs.getReports() );
-                if ( rs.getConfiguration() != null )
-                {
-                    ps.setConfiguration( new XmlPlexusConfiguration( (Xpp3Dom) rs.getConfiguration() ) );
+                ps.setId(rs.getId());
+                ps.setReports(rs.getReports());
+                if (rs.getConfiguration() != null) {
+                    ps.setConfiguration(new XmlPlexusConfiguration((Xpp3Dom) rs.getConfiguration()));
                 }
-                prs.add( ps );
+                prs.add(ps);
             }
-            p.setReportSets( prs );
+            p.setReportSets(prs);
 
             this.reportPlugins[i++] = p;
         }
